#include <rtx51.h>
#include <reg51.h>
#include <stdio.h>

// Task Definitions
#define STARTUP_TASK    3
#define TASK1           1
#define TASK2           2

// Semaphore Definitions
#define SEM_PRINTF      8

#define USE_SEMAPHORE   1



/***
make sure to link with...
ol(* ! ?PR?PRINTF?PRINTF)
***/


void setup_serial_io (void)
{
SCON  = 0x50;                   /* SCON: mode 1, 8-bit UART, enable rcvr */
TMOD |= 0x20;                   /* TMOD: timer 1, mode 2, 8-bit reload */
TH1   = 0xF0;                   /* TH1:  reload value */
TR1   = 1;                      /* TR1:  timer 1 run */
TI    = 1;                      /* TI:   set TI to send first char of UART */
}


void task_1 (void) _task_ TASK1 _priority_ 0
{
while (1)
  {
  os_wait (K_IVL, 150, 0);                                      // Delay for 250 ticks

#if USE_SEMAPHORE
  os_wait (K_MBX + SEM_PRINTF, 255, 0);                         // Wait for printf
  printf ("Task # %d\n", (int) os_running_task_id ());
  os_send_token (SEM_PRINTF);                                   // Done with printf
#else
  printf ("Task # %d\n", (int) os_running_task_id ());
#endif
  }
}


void task_2 (void) _task_ TASK2 _priority_ 1
{
while (1)
  {
  os_wait (K_IVL, 100, 0);                                      // Delay for 200 ticks

#if USE_SEMAPHORE
  os_wait (K_MBX + SEM_PRINTF, 255, 0);                         // Wait for printf
  printf ("Task # %d\n", (int) os_running_task_id ());
  os_send_token (SEM_PRINTF);                                   // Done with printf
#else
  printf ("Task # %d\n", (int) os_running_task_id ());
#endif
  }
}


void startup_task (void) _task_ STARTUP_TASK _priority_ 2
{
os_set_slice (1000);

os_create_task (TASK1);
os_create_task (TASK2);

#if USE_SEMAPHORE
  os_send_token (SEM_PRINTF);                                   // Setup printf semaphore
#endif

os_delete_task (os_running_task_id ());

while (1)
  {
  /*** This should never happen ***/
  }
}


void main (void)
{
setup_serial_io ();
printf ("Getting ready to start\n\n");

os_start_system (STARTUP_TASK);

while (1)
  {
  /*** This should never happen ***/
  }
}


